@@ -144,10 +144,23 @@ ggiplot = function(
   # Prep data for nested grouping
   has_groups = (!is.null(attributes(data)[["has_groups"]]) && isTRUE(attributes(data)[["has_groups"]]))
   if (isTRUE(has_groups)) {
-  	data[["x"]] = interaction(
-  		data[["x"]], data[["group_var"]],
-  		sep = "___", drop = TRUE#, lex.order = TRUE
-  		)
+
+  	key = unique(data[c("x", "group_var")])
+  	key = key[order(key[["group_var"]], key[["x"]]), , drop = FALSE]
+  	xlimits = as.character(key[["x"]])
+
+  	rle = rle(as.character(key[["group_var"]]))
+  	keep = nzchar(rle$values)
+  	end = cumsum(rle$lengths)
+  	start = end - rle$lengths + 1L
+
+  	key = legendry::key_range_manual(
+  		start = xlimits[start[keep]],
+  		end   = xlimits[end[keep]],
+  		name  = rle$values[keep],
+  		level = 1L
+  	)
+
   	data[["group_var"]] = NULL
   }
 
@@ -330,10 +343,15 @@ ggiplot = function(
        if (geom_style == "ribbon" || pt.join) {
            if (multi_style == "dodge") {
                if (length(ci_level) == 1) {
-                   geom_line(
-                       aes(group = paste0(.data$group, .data$id)),
-                       position = position_dodge(width = ci.width)
-                   )
+               		 if (identical(data$group, data$id)) {
+	                   geom_line(position = position_dodge2(width = ci.width, padding = ci.width))
+               		 } else {
+	                   geom_line(
+	                       aes(group = paste0(.data$group, .data$id)), # catch for complex split combos
+	                       position = position_dodge2(width = ci.width, padding = ci.width)
+	                   )
+
+               		 }
                } else {
                    geom_line(
                        data = ~ subset(.x, ci_level == max(ci_level)),
@@ -423,7 +441,13 @@ ggiplot = function(
    } +
    labs(x = xlab, y = ylab, title = main) + {
    	if (has_groups) {
-   		scale_x_discrete(guide = ggh4x::guide_axis_nested(delim = "___"))
+   		scale_x_discrete(
+   			limits = xlimits,
+   			guide = legendry::guide_axis_nested(
+   				key = key,
+   				theme = theme(legendry.bracket = element_line(linewidth = 0.5))
+   			)
+   		)
    	}
    } +
    {
@@ -457,11 +481,6 @@ ggiplot = function(
           )
   }
 
-  if (has_groups) {
-  	gg = gg +
-  		theme(ggh4x.axis.nestline = element_line(linewidth = 0.5))
-  }
-
   return(gg)
 
 }
